@@ -67,7 +67,7 @@ class DingDing_Push:
         res = requests.post(self.push_url, data=payload, headers=self.headers)
 
 # 自动登录；
-class sing_qimai:
+class Sing_Qimai:
     def __init__(self, user_id, user_pwd):
         self.user_id = user_id
         self.user_pwd = user_pwd
@@ -82,7 +82,7 @@ class sing_qimai:
         res = session.post(url, headers=headers, data=payload)
 
 # 计算七麦外的其他备用工具；
-class qimai_outside_tool:
+class Qimai_Outside_Tool:
     def __init__(self, data_info):
         self.data_info = data_info
 
@@ -157,7 +157,7 @@ class qimai_outside_tool:
         return self.trend
 
 # 计算七麦内的备用工具；
-class qimai_intside_tool:
+class Qimai_Intside_Tool:
     def rank_ios10_type(self, price):
         if price == '0.00' or price == '免费':
             return '总榜(免费)'
@@ -179,7 +179,7 @@ class qimai_intside_tool:
             return 0
 
 # 常用的自定义参数；
-class qimai_diy_var:
+class Qimai_Diy_Var:
     def __init__(self, country='cn', rank_type='all', version='ios12', device='iphone', search_type='all', brand='all', day=1, appRankShow=1, subclass='all', simple=1, rankEchartType=1, rankType='day', run_time=datetime.date.today(), status=6, keyword_hot_start=4605, typec='day', star='five', delete=-1, orderType='time', commentType='default', genre_type=36, status_type=3, clear_type=1, filter='offline', search_word='', export_type='rank_clear_words', sort_field='beforeClearNum', sort_type='desc', option=4):
         self.country = country
         self.rank_type = rank_type
@@ -213,9 +213,9 @@ class qimai_diy_var:
         self.option = option
 
 # 获取基础信息相关数据；
-class get_app_appinfo(qimai_diy_var):
+class Get_App_Appinfo(Qimai_Diy_Var):
     def __init__(self, appid):
-        qimai_diy_var.__init__(self)
+        Qimai_Diy_Var.__init__(self)
         self.appid = appid
 
     def get_appinfo(self):
@@ -230,9 +230,9 @@ class get_app_appinfo(qimai_diy_var):
         return self.subname
 
 # 获取榜单相关数据；
-class get_app_rank(qimai_diy_var):
+class Get_App_Rank(Qimai_Diy_Var):
     def __init__(self, appid, start_time, end_time):
-        qimai_diy_var.__init__(self)
+        Qimai_Diy_Var.__init__(self)
         self.appid = appid
         self.start_time = start_time
         self.end_time = end_time
@@ -257,12 +257,11 @@ class get_app_rank(qimai_diy_var):
         except:
             return []
 
-
 # 获取开发商相关数据；
-class get_app_samePubApp(get_app_appinfo, qimai_diy_var):
+class Get_App_SamePubApp(Get_App_Appinfo, Qimai_Diy_Var):
     def __init__(self, appid):
-        get_app_appinfo.__init__(self, appid)
-        qimai_diy_var.__init__(self)
+        Get_App_Appinfo.__init__(self, appid)
+        Qimai_Diy_Var.__init__(self)
 
     def get_samePubApp(self):
         url = 'https://api.qimai.cn/app/samePubApp?appid=%s&country=%s' %(self.appid, self.country)
@@ -279,9 +278,9 @@ class get_app_samePubApp(get_app_appinfo, qimai_diy_var):
                 return self.app_total_genid, self.app_class_genid
 
 # 获取关键词的相关数据；
-class get_keyword_info(qimai_diy_var):
+class Get_Keyword_Info(Qimai_Diy_Var):
     def __init__(self, keyword):
-        qimai_diy_var.__init__(self)
+        Qimai_Diy_Var.__init__(self)
         self.keyword = keyword
 
     def get_keyword_search(self):
@@ -302,9 +301,9 @@ class get_keyword_info(qimai_diy_var):
         return self.hints
 
 # 获取产品的关键词相关数据；
-class get_app_keyword(qimai_diy_var):
+class Get_App_Keyword(Qimai_Diy_Var):
     def __init__(self, appid):
-        qimai_diy_var.__init__(self)
+        Qimai_Diy_Var.__init__(self)
         self.appid = appid
 
     def get_keywordDetail(self):
@@ -334,9 +333,9 @@ class get_app_keyword(qimai_diy_var):
         return self.json_df
 
 # 获取产品评论的相关接口；
-class get_app_comment(qimai_diy_var):
+class Get_App_Comment(Qimai_Diy_Var):
     def __init__(self, appid, start_time, end_time):
-        qimai_diy_var.__init__(self)
+        Qimai_Diy_Var.__init__(self)
         self.appid = appid
         self.start_time = start_time
         self.end_time = end_time
@@ -363,10 +362,10 @@ class get_app_comment(qimai_diy_var):
         self.get_commentRateNum()
         df = pd.DataFrame({})
         for comment_info in self.app_commentRateNum['rateInfo']:
-            df_new = qimai_outside_tool(comment_info['data']).list_to_df()
+            df_new = Qimai_Outside_Tool(comment_info['data']).list_to_df()
             df = pd.concat([df, df_new])
         df.columns = ['日期', '评论数']
-        df['日期'] = df['日期'].apply(lambda x: qimai_outside_tool(x).time_to_date())
+        df['日期'] = df['日期'].apply(lambda x: Qimai_Outside_Tool(x).time_to_date())
         df = df.groupby('日期').sum()
         return df
 
@@ -375,17 +374,17 @@ class get_app_comment(qimai_diy_var):
         df = pd.DataFrame({})
         for comment_info in self.app_commentRateNum['rateInfo']:
             if comment_info['name'] == star_value:
-                df_new = qimai_outside_tool(comment_info['data']).list_to_df()
+                df_new = Qimai_Outside_Tool(comment_info['data']).list_to_df()
                 df = pd.concat([df, df_new])
         df.columns = ['日期', '评论数']
-        df['日期'] = df['日期'].apply(lambda x: qimai_outside_tool(x).time_to_date())
+        df['日期'] = df['日期'].apply(lambda x: Qimai_Outside_Tool(x).time_to_date())
         df = df.groupby('日期').sum()
         return df
 
 # 获取清榜列表相关数据；
-class get_clear_rank_list(qimai_diy_var):
+class Get_Clear_Rank_List(Qimai_Diy_Var):
     def __init__(self, start_time, end_time):
-        qimai_diy_var.__init__(self)
+        Qimai_Diy_Var.__init__(self)
         self.start_time = start_time
         self.end_time = end_time
 
@@ -402,9 +401,9 @@ class get_clear_rank_list(qimai_diy_var):
         return self.clear_rank_list
 
 # 获取清词列表相关数据；
-class get_clear_keyword_list(qimai_diy_var):
+class Get_Clear_Keyword_List(Qimai_Diy_Var):
     def __init__(self, start_time, end_time):
-        qimai_diy_var.__init__(self)
+        Qimai_Diy_Var.__init__(self)
         self.start_time = start_time
         self.end_time = end_time
 
@@ -421,9 +420,9 @@ class get_clear_keyword_list(qimai_diy_var):
         return self.clear_word_list
 
 # 获取下架产品列表相关数据；
-class get_app_offline_list(qimai_diy_var):
+class Get_App_Offline_List(Qimai_Diy_Var):
     def __init__(self, start_time, end_time):
-        qimai_diy_var.__init__(self)
+        Qimai_Diy_Var.__init__(self)
         self.start_time = start_time
         self.end_time = end_time
 
@@ -439,6 +438,24 @@ class get_app_offline_list(qimai_diy_var):
                 break
         return self.app_offline_list
 
+# 获取产品被精品推荐及上热搜情况列表；
+class Get_App_Recommend(Qimai_Diy_Var):
+    def __init__(self, appid):
+        Qimai_Diy_Var.__init__(self)
+        self.appid = appid
+
+    def app_featured(self):
+        url = 'https://api.qimai.cn/app/featured?country=%s&appid=%s' %(self.country, self.appid)
+        res = session.get(url, headers=headers)
+        self.app_featured = res.json()
+        return self.app_featured
+
+    def app_engagement(self, start_time, end_time):
+        url = 'https://api.qimai.cn/app/engagement'
+        payload='app_id=%s&s_date=%s&e_date=%s' %(self.appid, start_time, end_time)
+        res = session.post(url, data=payload, headers=headers)
+        self.app_engagement = res.json()
+        return self.app_engagement
 
 
 
