@@ -5,11 +5,11 @@ import threading
 
 threadLock = threading.Lock()
 
-class top_keyword_Thread(threading.Thread):
+class Top_Keyword_Thread(threading.Thread):
     def __init__(self, threadID, *args):
         threading.Thread.__init__(self)
         self.appid = threadID
-        self.name = get_app_appinfo(args[0]).get_subname()
+        self.name = Get_App_Appinfo(args[0]).get_subname()
         self.args = args
 
     def Thread_run(self):
@@ -21,7 +21,7 @@ class top_keyword_Thread(threading.Thread):
         # 释放锁，开启下一个线程
         threadLock.release()
 
-class top_multiple_keyword_Thread:
+class Top_Multiple_Keyword_Thread:
     def __init__(self, appid_list, keyword_hot_start, start_time, end_time, file_path='./'):
         self.appid_list = appid_list
         self.keyword_hot_start = keyword_hot_start
@@ -33,7 +33,7 @@ class top_multiple_keyword_Thread:
         threads = []
 
         for num, appid in enumerate(self.appid_list):
-            thread = top_keyword_Thread(num+1, *[appid, self.keyword_hot_start, self.start_time, self.end_time, self.file_path])
+            thread = Top_Keyword_Thread(num+1, *[appid, self.keyword_hot_start, self.start_time, self.end_time, self.file_path])
             thread.start()
             threads.append(thread)
 
